** -----------------------------------------------------------------------------
** Earnings regressions
** Estimates of age profiles and returns to education in earnings
** -----------------------------------------------------------------------------


drop _all
clear matrix
cd "C:\EMar"

clear matrix
global gender "m w"

foreach g of global gender {

	qui use "data\BHPSall.dta", replace
	qui keep if `g'pid<.
		
	qui gen s=`g's23
	qui replace s=`g'Sadult if s==.
	qui ta s, g(s)
		
	qui keep if (`g'_insampleWL==1 | `g'_insampleEduc==1) & `g'age<=50
	qui sort `g'pid wave
	qui by `g'pid: gen n=_n
		
	qui gen dkid = (ownkid>0)
	qui gen k04  = inrange(yngkid,0,4)
	qui gen k510 = inrange(yngkid,5,10)

	qui gen age  = (`g'age-23)/10
	qui gen age2 = age*age
	qui gen age3 = age*age*age

	qui gen pYmiss = (`g'pYres>=.)
	qui rename `g'pYres pYres
	qui replace pYres=0 if pYmiss==1
	qui gen pYres2 = pYres*pYres

	** education choice
	qui eststo ed`g': mlogit s pYres pYres2 pYmiss if n==1
	qui predict xbS2, pr outcome(2)
	qui predict xbS3, pr outcome(3)
	qui gen xbS2sq = xbS2*xbS2
	qui gen xbS3sq = xbS3*xbS3
	qui gen xbS23  = xbS2*xbS3

	** selection into work		
	if ("`g'"=="m") local pg "w"
	if ("`g'"=="w") local pg "m"
	qui qui gen pwork=`pg'dE if couple==1
	qui qui replace pwork = 0  if couple==0
		
	qui regress famY0h`g' dkid k04 k510 couple pwork                            ///
	                      if mwkl==1 & inrange(`g'age,23,50)
	qui predict r if e(sample), r
	qui eststo E`g': probit `g'dE i.`g'yob i.wave pYres pYres2 pYmiss r         ///
	                        if `g'wkli==1 & inrange(`g'age,23,50)
	qui predict xb if e(sample), xb
	qui gen millsE =  normalden(-xb)/(1-normal(-xb)) if `g'd==1
	qui gen millsEsq = millsE*millsE
	qui drop xb 

	** earnings regression
	qui eststo lY`g': regress `g'lY i.s i.s#c.age i.s#c.age2 i.s#c.age3         ///
	                      xbS2 xbS3 xbS2sq xbS3sq xbS23 millsE millsEsq         ///
						  if `g'dE==1 & inrange(`g'age,23,50) & `g'wkli==1
	forvalues s=1/3 {
		global `g'ca`s'   = _b[`s'.s#c.age]
		global `g'ca`s'sq = _b[`s'.s#c.age2]
		global `g'ca`s'cb = _b[`s'.s#c.age3]
	}
		
}


esttab edm edw, nonum ti(Education regressions - multinomial logit)             ///
    mtitles(men women) starlevels(* 0.10 ** 0.05 *** 0.01) cells(b(fmt(3) star) ///
	se(par fmt(3))) coeflabels(pYres "res: parental income"                     ///
	pYres2 "res sq: parental income" pYmiss "parental income missing"           ///
	_cons "intercept")                                                          ///
	keep(2:pYres 2:pYres2 2:pYmiss 2:_cons 3:pYres 3:pYres2 3:pYmiss 3:_cons)

esttab Em Ew, nonum ti(Employment regressions - probit) mtitles(men women)      ///
	starlevels(* 0.10 ** 0.05 *** 0.01) cells(b(fmt(3) star) se(par fmt(3)))    ///
	keep(pYres pYres2 r _cons) coeflabels(pYres "parental income residual"      ///
	pYres2 "parental income residual squared"                                   ///
	r "income if not working residual" _cons "intercept") 

esttab lYm lYw, nonum ti(Earnings regressions) mtitles(men men women women)     ///
	starlevels(* 0.10 ** 0.05 *** 0.01) cells(b(fmt(3) star) se(par fmt(3)))    ///
	keep(2.s 3.s 1.s#c.age 2.s#c.age 3.s#c.age 1.s#c.age2 2.s#c.age2 3.s#c.age2 ///
	1.s#c.age3 2.s#c.age3 3.s#c.age3)                                           ///
	coeflabels(2.s "HS" 3.s "Univ" 1.s#c.age "age x Sec" 2.s#c.age "age x HS"   ///
	3.s#c.age "age x Univ" 1.s#c.age2 "age sq x Sec" 2.s#c.age2 "age sq x HS"   ///
	3.s#c.age2 "age sq x Univ" 1.s#c.age3 "age cb x Sec"                        ///
	2.s#c.age3 "age cb x HS" 3.s#c.age3 "age cb x Univ" ) 

